@@ -1,16 +1,16 @@
-__version__ = '0.4'
+__version__ = '0.5'
 
 __all__ = ['Label', 'Instr', 'SetLineno', 'Bytecode',
            'ConcreteInstr', 'ConcreteBytecode',
            'ControlFlowGraph']
 
-from bytecode.instr import (UNSET, Label, SetLineno, Instr, CellVar, FreeVar,
+from bytecode.instr import (UNSET, Label, SetLineno, Instr, CellVar, FreeVar,   # noqa
                             Compare)
-from bytecode.bytecode import BaseBytecode, _InstrList, Bytecode
-from bytecode.concrete import (ConcreteInstr, ConcreteBytecode,
+from bytecode.bytecode import BaseBytecode, _InstrList, Bytecode   # noqa
+from bytecode.concrete import (ConcreteInstr, ConcreteBytecode,   # noqa
                                # import needed to use it in bytecode.py
                                _ConvertBytecodeToConcrete)
-from bytecode.cfg import BasicBlock, ControlFlowGraph
+from bytecode.cfg import BasicBlock, ControlFlowGraph   # noqa
 
 
 def dump_bytecode(bytecode, *, lineno=False):
@@ -56,7 +56,7 @@ def dump_bytecode(bytecode, *, lineno=False):
         for instr in bytecode:
             fields = []
             if instr.lineno is not None:
-               cur_lineno = instr.lineno
+                cur_lineno = instr.lineno
             if lineno:
                 fields.append(format_instr(instr))
                 line = ''.join(fields)
@@ -81,7 +81,7 @@ def dump_bytecode(bytecode, *, lineno=False):
                     print()
             else:
                 if instr.lineno is not None:
-                   cur_lineno = instr.lineno
+                    cur_lineno = instr.lineno
                 line = format_instr(instr, labels)
                 line = indent + format_line(index, line)
             print(line)
@@ -96,7 +96,7 @@ def dump_bytecode(bytecode, *, lineno=False):
             prev_lineno = None
             for index, instr in enumerate(block):
                 if instr.lineno is not None:
-                   cur_lineno = instr.lineno
+                    cur_lineno = instr.lineno
                 line = format_instr(instr, labels)
                 line = indent + format_line(index, line)
                 print(line)
